==> dde-launcher_4.4.5.5.orig.tar.xz: dde-launcher-4.4.5.5/translations/dde-launcher_uk.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="uk" version="2.1">
<context>
    <name>AppsManager</name>
    <message>
        <source>No search results</source>
        <translation>Немає результатів пошуку</translation>
    </message>
    <message>
        <source>Internet</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Chat</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Music</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Video</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Graphics</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Game</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Office</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Reading</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Development</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>System</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Others</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>FullScreenFrame</name>
    <message>
        <source>Are you sure to uninstall %1 ?</source>
        <translation>Ви впевнені, що хочете видалити %1 ?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Скасувати</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Підтвердити</translation>
    </message>
</context>
<context>
    <name>MenuWorker</name>
    <message>
        <source>Remove from desktop</source>
        <translation>Видалити з робочого столу</translation>
    </message>
    <message>
        <source>Remove from dock</source>
        <translation>Видалити з док-панелі</translation>
    </message>
    <message>
        <source>Uninstall</source>
        <translation>Видалити</translation>
    </message>
    <message>
        <source>Open by proxy</source>
        <translation>Відкрити через проксі</translation>
    </message>
    <message>
        <source>Disable display scaling</source>
        <translation>Вимкнути масштабування дисплею</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Відкрити</translation>
    </message>
    <message>
        <source>Send to desktop</source>
        <translation>Надіслати на стільницю</translation>
    </message>
    <message>
        <source>Send to dock</source>
        <translation>Надіслати на панель</translation>
    </message>
    <message>
        <source>Remove from startup</source>
        <translation>Вилучити із запуску</translation>
    </message>
    <message>
        <source>Add to startup</source>
        <translation>Додати до запуску</translation>
    </message>
</context>
<context>
    <name>MiniCategoryWidget</name>
    <message>
        <source>All Apps</source>
        <translation>Усі додатки</translation>
    </message>
    <message>
        <source>Internet</source>
        <translation>Інтернет</translation>
    </message>
    <message>
        <source>Chat</source>
        <translation>Чат</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Музика</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Відео</translation>
    </message>
    <message>
        <source>Graphics</source>
        <translation>Графіка</translation>
    </message>
    <message>
        <source>Game</source>
        <translation>Гра</translation>
    </message>
    <message>
        <source>Office</source>
        <translation>Офіс</translation>
    </message>
    <message>
        <source>Reading</source>
        <translation>Читання</translation>
    </message>
    <message>
        <source>Development</source>
        <translation>Розробка</translation>
    </message>
    <message>
        <source>System</source>
        <translation>Система</translation>
    </message>
    <message>
        <source>Others</source>
        <translation>Інші</translation>
    </message>
</context>
<context>
    <name>MiniFrame</name>
    <message>
        <source>Are you sure to uninstall %1 ?</source>
        <translation>Ви впевнені, що хочете видалити %1 ?</translation>
    </message>
    <message>
        <source>All dependencies will be removed together</source>
        <translation>Всі залежності будуть видалені разом</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Скасувати</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Підтвердити</translation>
    </message>
</context>
<context>
    <name>MiniFrameBottomBar</name>
    <message>
        <source>Computer</source>
        <translation>Комп&apos;ютер</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>Документи</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Відео</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Музика</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Зображення</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Завантаження</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Заблокувати</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation>Вийти</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Перезавантажити</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Призупинити</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Вимкнення</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Назад</translation>
    </message>
</context>
<context>
    <name>MiniFrameNavigation</name>
    <message>
        <source>Computer</source>
        <translation>Комп&apos;ютер</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Музика</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Вимкнення</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Заблокувати</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation>Вийти</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Перезавантажити</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Призупинити</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Назад</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>Документи</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Відео</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Зображення</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Завантаження</translation>
    </message>
</context>
<context>
    <name>MiniFrameRightBar</name>
    <message>
        <source>Computer</source>
        <translation>Комп&apos;ютер</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Музика</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Завантаження</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Інструкція</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Налаштування</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Вимкнення</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Відео</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Зображення</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MiniFrameSwitchBtn</name>
    <message>
        <source>All Categories</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Back</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Пошук</translation>
    </message>
</context>
<context>
    <name>WindowedFrame</name>
    <message>
        <source>Are you sure to uninstall %1 ?</source>
        <translation>Ви впевнені, що хочете видалити %1 ?</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Скасувати</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Підтвердити</translation>
    </message>
</context>
</TS>

==> dde-launcher_4.6.13.orig.tar.xz: dde-launcher-4.6.13/translations/dde-launcher_uk.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="uk" version="2.1">
<context>
    <name>AppsManager</name>
    <message>
        <source>No search results</source>
        <translation>Немає результатів пошуку</translation>
    </message>
    <message>
        <source>Internet</source>
        <translation>Інтернет</translation>
    </message>
    <message>
        <source>Chat</source>
        <translation>Спілкування</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Музика</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Відео</translation>
    </message>
    <message>
        <source>Graphics</source>
        <translation>Графіка</translation>
    </message>
    <message>
        <source>Office</source>
        <translation>Офіс</translation>
    </message>
    <message>
        <source>Reading</source>
        <translation>Читання</translation>
    </message>
    <message>
        <source>Development</source>
        <translation>Розробка</translation>
    </message>
    <message>
        <source>System</source>
        <translation>Система</translation>
    </message>
    <message>
        <source>Games</source>
        <translation>Ігри</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Інше</translation>
    </message>
</context>
<context>
    <name>FullScreenFrame</name>
    <message>
        <source>Cancel</source>
        <translation>Скасувати</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Підтвердити</translation>
    </message>
    <message>
        <source>Are you sure you want to uninstall %1 ?</source>
        <translation>Ви впевнені, що хочете видалити %1 ?</translation>
    </message>
</context>
<context>
    <name>MenuWorker</name>
    <message>
        <source>Remove from desktop</source>
        <translation>Видалити з стільниці</translation>
    </message>
    <message>
        <source>Remove from dock</source>
        <translation>Видалити з док-панелі</translation>
    </message>
    <message>
        <source>Uninstall</source>
        <translation>Видалити</translation>
    </message>
    <message>
        <source>Disable display scaling</source>
        <translation>Вимкнути масштабування дисплею</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Відкрити</translation>
    </message>
    <message>
        <source>Send to desktop</source>
        <translation>Надіслати на стільницю</translation>
    </message>
    <message>
        <source>Send to dock</source>
        <translation>Надіслати на панель</translation>
    </message>
    <message>
        <source>Remove from startup</source>
        <translation>Вилучити із запуску</translation>
    </message>
    <message>
        <source>Add to startup</source>
        <translation>Додати до запуску</translation>
    </message>
    <message>
        <source>Use a proxy</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MiniCategoryWidget</name>
    <message>
        <source>All Apps</source>
        <translation>Усі додатки</translation>
    </message>
    <message>
        <source>Internet</source>
        <translation>Інтернет</translation>
    </message>
    <message>
        <source>Chat</source>
        <translation>Чат</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Музика</translation>
    </message>
    <message>
        <source>Video</source>
        <translation>Відео</translation>
    </message>
    <message>
        <source>Graphics</source>
        <translation>Графіка</translation>
    </message>
    <message>
        <source>Game</source>
        <translation>Гра</translation>
    </message>
    <message>
        <source>Office</source>
        <translation>Офіс</translation>
    </message>
    <message>
        <source>Reading</source>
        <translation>Читання</translation>
    </message>
    <message>
        <source>Development</source>
        <translation>Розробка</translation>
    </message>
    <message>
        <source>System</source>
        <translation>Система</translation>
    </message>
    <message>
        <source>Others</source>
        <translation>Інші</translation>
    </message>
</context>
<context>
    <name>MiniFrameBottomBar</name>
    <message>
        <source>Computer</source>
        <translation>Комп&apos;ютер</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>Документи</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Відео</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Музика</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Зображення</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Завантаження</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Заблокувати</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation>Вийти</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Перезавантажити</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Призупинити</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Вимкнення</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Назад</translation>
    </message>
</context>
<context>
    <name>MiniFrameNavigation</name>
    <message>
        <source>Computer</source>
        <translation>Комп&apos;ютер</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Музика</translation>
    </message>
    <message>
        <source>Shutdown</source>
        <translation>Вимкнення</translation>
    </message>
    <message>
        <source>Lock</source>
        <translation>Заблокувати</translation>
    </message>
    <message>
        <source>Logout</source>
        <translation>Вийти</translation>
    </message>
    <message>
        <source>Reboot</source>
        <translation>Перезавантажити</translation>
    </message>
    <message>
        <source>Suspend</source>
        <translation>Призупинити</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Назад</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>Документи</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Відео</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Зображення</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Завантаження</translation>
    </message>
</context>
<context>
    <name>MiniFrameRightBar</name>
    <message>
        <source>Computer</source>
        <translation>Комп&apos;ютер</translation>
    </message>
    <message>
        <source>Music</source>
        <translation>Музика</translation>
    </message>
    <message>
        <source>Downloads</source>
        <translation>Завантаження</translation>
    </message>
    <message>
        <source>Manual</source>
        <translation>Інструкція</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Налаштування</translation>
    </message>
    <message>
        <source>Videos</source>
        <translation>Відео</translation>
    </message>
    <message>
        <source>Pictures</source>
        <translation>Зображення</translation>
    </message>
    <message>
        <source>Documents</source>
        <translation>Документи</translation>
    </message>
    <message>
        <source>Power</source>
        <translation>Акумулятор</translation>
    </message>
</context>
<context>
    <name>MiniFrameSwitchBtn</name>
    <message>
        <source>All Categories</source>
        <translation>Усі категорії</translation>
    </message>
    <message>
        <source>Back</source>
        <translation>Назад</translation>
    </message>
</context>
<context>
    <name>SearchLineEdit</name>
    <message>
        <source>Search</source>
        <translation>Пошук</translation>
    </message>
</context>
<context>
    <name>WindowedFrame</name>
    <message>
        <source>Cancel</source>
        <translation>Скасувати</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>Підтвердити</translation>
    </message>
    <message>
        <source>Are you sure you want to uninstall %1 ?</source>
        <translation>Ви впевнені, що хочете видалити %1 ?</translation>
    </message>
</context>
</TS>
